@@ -15,6 +15,7 @@ except ImportError:                                     #pragma:nocover
     using_yaml=False
 
 import plugins
+import pyutilib.misc
 from pyutilib.component.core import *
 
 
@@ -27,8 +28,16 @@ class YamlTestParser(SingletonPlugin):
         self.name='yml'
 
     def load_test_config(self, filename):
+        if using_yaml:
+            INPUT = open(filename, 'r')
+            repn = yaml.load(INPUT, yaml.SafeLoader)
+            INPUT.close()
+            return repn
+        #
+        # If PyYaml is not available, then we use a simple yaml parser
+        #
         INPUT = open(filename, 'r')
-        repn = yaml.load(INPUT, yaml.SafeLoader)
+        repn = pyutilib.misc.simple_yaml_parser(INPUT)
         INPUT.close()
         return repn
 
@@ -36,4 +45,4 @@ class YamlTestParser(SingletonPlugin):
         print repn                                      #pragma:nocover
 
     def enabled(self):
-        return using_yaml
+        return True
